;; Generated package description from pinentry.el  -*- no-byte-compile: t -*-
(define-package "pinentry" "0.1.0.20241123.141" "GnuPG Pinentry server implementation" 'nil :commit "77991a491f3fc4673dfdd959ba6b4c9b0111150f" :authors '(("Daiki Ueno" . "ueno@gnu.org")) :maintainer '("Daiki Ueno" . "ueno@gnu.org") :keywords '("gnupg") :url "https://github.com/ueno/pinentry-el")
